# -*- coding:utf-8 -*-
import json

import requests


def current(keyword):
	url = ''.join(('http://markets.money.cnn.com/services/api/mobile/companydetails.asp?outputFormat=JSONP&callback=angular.callbacks._0&symb=', keyword))
	return json.loads(requests.get(url).text[28:-2])		


def search( keyword):
	url = ''.join(('http://markets.money.cnn.com/services/mobile/lookup.asp?render=json&jsoncallback=angular.callbacks._a&symb=', keyword))
	return json.loads(requests.get(url).text[27:-3])


# -*- coding:utf-8 -*-
import json

import requests
from bs4 import BeautifulSoup


def search(keyword):
	url = "".join(('https://s.yimg.com/aq/autoc?query=', keyword, '&region=US&lang=en-US&callback=YAHOO.util.ScriptNodeDataSource.callbacks'))
	return json.loads(requests.get(url).text[42:-1])


def index(keyword):
	url = "".join(('http://finance.yahoo.com/q?s=', keyword))
	html = BeautifulSoup(requests.get(url).text, 'html.parser')
	print(html.findAll('span'))
	#return html.find('span', id='priceLegend'), html.find('span', id='legendPriceChange'), html.find('span', id='legendPctChange')#html.find('div', id='legendData').find('div', 'symbol-name'), html.find('span', id='priceLegend'), html.find('span', id='legendPriceChange'), html.find('span', id='legendPctChange')
	

def test(keyword):
	headers = {
		'Accept': '*/*',
		'Accept-Encoding': 'gzip, deflate, sdch',
		'Accept-Language': 'ko-KR,ko;q=0.8,en-US;q=0.6,en;q=0.4',
		'Connection': 'keep-alive',
		'Host': 'finance.yahoo.com',
		'Referer': 'http://finance.yahoo.com/q?s=^KS11',
		'User-Agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 7_0 like Mac OS X; en-us) AppleWebKit/537.51.1 (KHTML, like Gecko) Version/7.0 Mobile/11A465 Safari/9537.53',
		'X-Requested-With': 'XMLHttpRequest',
		'Cookie': 'B=52o6gn9al00dn&b=3&s=ko; ywandp=1000911397279%3A4125726577; fpc=1000911397279%3AZUk4bVZE%7C%7C; ypcdb=93e8aebc5f16756a5402764abbdbca4e; ywadp115488662=3024871490; GG=eyJmaW5hbmNlLnwiOnsidCI6MTQzNzEwMTY4Nn19; yvapF=%7B%22cc%22%3A1%2C%22rcc%22%3A1%2C%22vl%22%3A1.318%2C%22rvl%22%3A1.318%2C%22al%22%3A1%7D; PRF==undefined&t=%5EKS11'
	}
	url = "".join((
		'http://finance.yahoo.com/__td_finance_api/resource/charts;comparisonTickers=;indicators=quote;queryString={"s":"', 
		keyword, 
		'"};range=1d;rangeSelected=;ticker=', 
		keyword, 
		';useMock=false?crumb=0lVU/cVsiHK&lang=en-US&region=US'
	))
	return requests.get(url, headers=headers).text	



# -*- coding:utf-8 -*-
from __future__ import print_function
import sys

from .index import current, search
from .prompt import colored as  c


def runner():
	if len(sys.argv) == 2:
		option, keyword = 'current', sys.argv[1]
	elif len(sys.argv) == 3:
		option, keyword = sys.argv[1], sys.argv[2]
	else:
		print('Usage:', c('pyprice [option: search] keyword', 'sian'))
		raise SystemExit(1)

	if option == 'current':
		try:
			data = current(keyword)
			print(c(data['companyName'], 'magenta'), '/', c(data['keys']['displaySymbol'], 'yellow'))
			print(c('Current Price', 'sian')+':', data['value'], end=' (')
			price_color = 'red' if '-' in data['change'] else 'blue'
			print(c(data['change'], price_color)+',', c(data['pctChange'], price_color)+'%)')
			print(c('Market', 'sian')+':', data['exchange'])
		except ValueError:
			print(c('Can not find keyword.', 'red'), 'Try', c('pynance search '+keyword, 'sian'))

	elif option == 'search':
		results = search(keyword)
		if len(results) == 0:
			print(c('Can not find keyword.', 'red'))
		else:
			for result in results:
				data = result[0]
				print(c('Name', 'sian')+':', c(data['n'], 'magenta'))
				print(c('Keyword', 'sian')+':', c(data['s'], 'yellow'))
				print(c('Market', 'sian')+':', data['e'], '\n')

	else:
		print(c('Not supported option.', 'red'))


if __name__ == '__main__':
	runner()


"""
pyprice
-------
stock price index wrapper.
"""

from os import path
from setuptools import setup

from pyprice import VERSION


long_description = open(
    path.join(
        path.dirname(__file__),
        'README.rst'
    )
).read()

setup(
    name='pyprice',
    version=VERSION,
    url='https://github.com/Parkayun/pyprice',
    license='MIT',
    author='Ayun Park',
    author_email='iamparkayun@gmail.com',
    description='stock price index wrapper.',
    long_description=long_description,
    packages=['pyprice'],
    install_requires=[
        'requests',
    ],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    entry_points={
        'console_scripts': [
            'pyprice=pyprice.cli:runner',
        ],
    },
)